==> flink-1.12.7-src.tgz: flink-1.12.7/flink-libraries/flink-gelly/src/test/java/org/apache/flink/graph/types/valuearray/NullValueArraySerializerTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.graph.types.valuearray;

import org.apache.flink.api.common.typeutils.TypeSerializer;
import org.apache.flink.types.NullValue;

/** A test for the {@link NullValueArraySerializer}. */
public class NullValueArraySerializerTest extends ValueArraySerializerTestBase<NullValueArray> {

    @Override
    protected TypeSerializer<NullValueArray> createSerializer() {
        return new NullValueArraySerializer();
    }

    @Override
    protected int getLength() {
        return 4;
    }

    @Override
    protected Class<NullValueArray> getTypeClass() {
        return NullValueArray.class;
    }

    @Override
    protected NullValueArray[] getTestData() {
        NullValue nv = NullValue.getInstance();

        NullValueArray nva0 = new NullValueArray();

        NullValueArray nva1 = new NullValueArray();
        nva1.addAll(nva0);
        nva1.add(nv);

        NullValueArray nva2 = new NullValueArray();
        nva2.addAll(nva1);
        nva2.add(nv);

        NullValueArray nva3 = new NullValueArray();
        nva3.addAll(nva2);
        for (int i = 0; i < 100; i++) {
            nva3.add(nv);
        }
        nva3.addAll(nva3);

        return new NullValueArray[] {nva0, nva1, nva2, nva3};
    }
}

==> flink-1.16.3-src.tgz: flink-1.16.3/flink-libraries/flink-gelly/src/test/java/org/apache/flink/graph/types/valuearray/NullValueArraySerializerTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.graph.types.valuearray;

import org.apache.flink.api.common.typeutils.TypeSerializer;
import org.apache.flink.types.NullValue;

/** A test for the {@link NullValueArraySerializer}. */
class NullValueArraySerializerTest extends ValueArraySerializerTestBase<NullValueArray> {

    @Override
    protected TypeSerializer<NullValueArray> createSerializer() {
        return new NullValueArraySerializer();
    }

    @Override
    protected int getLength() {
        return 4;
    }

    @Override
    protected Class<NullValueArray> getTypeClass() {
        return NullValueArray.class;
    }

    @Override
    protected NullValueArray[] getTestData() {
        NullValue nv = NullValue.getInstance();

        NullValueArray nva0 = new NullValueArray();

        NullValueArray nva1 = new NullValueArray();
        nva1.addAll(nva0);
        nva1.add(nv);

        NullValueArray nva2 = new NullValueArray();
        nva2.addAll(nva1);
        nva2.add(nv);

        NullValueArray nva3 = new NullValueArray();
        nva3.addAll(nva2);
        for (int i = 0; i < 100; i++) {
            nva3.add(nv);
        }
        nva3.addAll(nva3);

        return new NullValueArray[] {nva0, nva1, nva2, nva3};
    }
}
